/**
 * Provides a set of methods and tools to work with the JSON Web Token (jwt).
 *
 * ### Examples
 * Request a jwt (JSON Web Token) and send it to an iframe using postMessage.
 *
 * JavaScript:
 *
 *     require([
 *         "jquery",
 *         "de_epages/shop/inc/jwt-tools",
 *
 *         "$ready!"
 *     ], function ($, jwt) {
 *
 *         var iframeId = '#' + 'EmbeddedUnityStorefront',
 *             iframe = document.querySelector(iframeId);
 *
 *         window.setInterval(function () {
 *             // request token and hand over callback to post new token to iframe
 *             jwt.requestToken({
 *                 url: '#BaseLineContentLocation',
 *                 ViewAction: 'JSONViewResponse',
 *                 ChangeAction: 'JSONCreateJWT',
 *                 ChangeObjectID: #Shop.ID
 *             },
 *             function(data) {
 *                 iframe.contentWindow.postMessage({type: 'TOKEN', payload: data.jwt}, unityHostAndPort);
 *             });
 *         }, 150000); // 150000 = 2m 30s
 *     });
 *
 * @class de_epages.shop.inc.jwt-tools
 *
 * @uses ep
 * @since 7.9.0
 */

/**
 * Request a jwt (JSON Web Token) and executes a handed over callback function.
 *
 * @param {Object} options A map of options pass to the method.
 * @param {Function} callback Function that should be executed after AJAX request was sucessfully.
 *
 * @method requestToken
 * @member de_epages.shop.inc.jwt-tools
 *
 * @since 7.9.0
 */

/*
 * @copyright       © Copyright 2006-2017, epages GmbH, All Rights Reserved.
 *
 * @module          de_epages.shop.inc.jwt-tools
 *
 * @revision        $Revision: 1.20 $
 */

/*globals define*/
/*jslint nomen: true*/

define("de_epages/shop/inc/jwt-tools", [
    "jquery",
    "ep"
], function ($, ep) {

    return {
        // method to request a valid JSON Web Token (jwt) and execute a handed over callback function
        requestToken: function (options, callback) {
            var o = $.extend({
                //  ChangeObjectID: 0,
                    url: "?",
                    ViewAction: 'JSONViewResponse',
                    ChangeAction: 'JSONCreateJWT'
                }, options);

            if (o.ChangeObjectID) {
                ep.ajax({
                    url: o.url,
                    dataType: 'json',
                    data: {
                        ViewAction: o.ViewAction,
                        ChangeObjectID: o.ChangeObjectID,
                        ChangeAction: o.ChangeAction
                    }
                })
                .done(function (data) {
                    callback(data);
                })
                .fail(function (xhr, status, error) {
                    console.warn(error);
                });
            }
        }
    };

});
